@@ -2,6 +2,7 @@
 import progressbar
 import threading
 import requests
+import re
 from bs4 import BeautifulSoup
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
@@ -1697,6 +1698,54 @@ class API:
 
         _api_change_pw.change_pw(self, new_password)
 
+    def get_aid_from_url(self, url: str) -> (str, str):
+
+        # 檢查是否為字串
+        check_value.check(self.config, str, 'url', url)
+
+        # 檢查是否符合 PTT BBS 文章網址格式
+        pattern = re.compile('https://www.ptt.cc/bbs/[-.\w]+/M.[\d]+.A[.\w]*.html')
+        r = pattern.search(url)
+        if r is None:
+            raise ValueError(log.merge(
+                self.config,
+                [
+                    i18n.ErrorParameter,
+                    'url must be www.ptt.cc article url'
+                ]))
+
+        # 演算法參考 https://www.ptt.cc/man/C_Chat/DE98/DFF5/DB61/M.1419434423.A.DF0.html
+        # aid 字元表
+        aid_table = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz-_'
+
+        board = url[23:]
+        board = board[:board.find('/')]
+
+        temp = url[url.rfind('/') + 1:].split('.')
+        # print(temp)
+
+        id_0 = int(temp[1])  # dec
+
+        aid_0 = ''
+        for _ in range(6):
+            index = id_0 % 64
+            aid_0 = f'{aid_table[index]}{aid_0}'
+            id_0 = int(id_0 / 64)
+
+        if temp[3] != 'html':
+            id_1 = int(temp[3], 16)  # hex
+            aid_1 = ''
+            for _ in range(2):
+                index = id_1 % 64
+                aid_1 = f'{aid_table[index]}{aid_1}'
+                id_1 = int(id_1 / 64)
+        else:
+            aid_1 = '00'
+
+        aid = f'{aid_0}{aid_1}'
+
+        return board, aid
+
 
 if __name__ == '__main__':
     print('PyPtt v ' + version.V)
